#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MIN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MIN_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/min.hpp>

#endif
